function [ E ] = intenzitavbode( d_pr,d_od,E0,f,R,vzd,vzd_m1,vzd_m2 ) %přímý paprsek a odraz od vodní hladiny
% VSTUP: d_pr   - delka primeho paprsku
%        d_od   - delka odrazeneho paprsku
%        E0     - pocatecni intenzita pole
%        f      - frekvence vlny [MHz]
%        R      - koeficient odrazu
vln=((3*10^(8))/(f*10^(6)));
k=((2*pi())/(vln));

%if (vzd<=vzd_m1 && vzd>=vzd_m2)
if (vzd>=vzd_m1 && vzd<=vzd_m2)
    E1=((E0/d_od)*exp(-1i*k*d_od))*(R*exp(-1i*pi()));
else
    E1=((E0/d_pr)*exp(-1i*k*d_pr))+((E0/d_od)*exp(-1i*k*d_od))*(R*exp(-1i*pi()));
end
E=E1;
end

